/**
 * \file src/input/mzidentml/msrunlocationreader.cpp
 * \date 16/7/2022
 * \author Olivier Langella
 * \brief parse mzIdentML result file to only get the msrun
 */


/*******************************************************************************
 * Copyright (c) 2022 Olivier Langella
 *<Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of i2MassChroQ.
 *
 *     i2MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     i2MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with i2MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/

#include "msrunlocationreader.h"
#include <QDebug>

MsRunLocationReader::MsRunLocationReader()
{
}

MsRunLocationReader::~MsRunLocationReader()
{
}


void
MsRunLocationReader::readStream()
{

  bool is_spectradata = false;

  qDebug();
  if(m_qxmlStreamReader.readNextStartElement())
    {
      qDebug() << m_qxmlStreamReader.name();
      if(m_qxmlStreamReader.name().toString() == "MzIdentML")
        {
          while(m_qxmlStreamReader.readNextStartElement())
            {
              qDebug() << m_qxmlStreamReader.name();
              if(m_qxmlStreamReader.name().toString() != "DataCollection")
                {
                  m_qxmlStreamReader.skipCurrentElement();
                }
              else
                {
                  //<DataCollection
                  while(m_qxmlStreamReader.readNextStartElement())
                    {
                      qDebug() << m_qxmlStreamReader.name();
                      if(m_qxmlStreamReader.name().toString() != "Inputs")
                        {
                          m_qxmlStreamReader.skipCurrentElement();
                        }
                      else
                        {
                          // <Inputs>
                          while(m_qxmlStreamReader.readNextStartElement())
                            {
                              qDebug() << m_qxmlStreamReader.name();
                              if(m_qxmlStreamReader.name().toString() ==
                                 "SpectraData")
                                {
                                  is_spectradata = true;
                                  readSpectraData();
                                }
                              else
                                {
                                  m_qxmlStreamReader.skipCurrentElement();
                                }
                            }
                          if(is_spectradata == false)
                            {
                              m_qxmlStreamReader.raiseError(
                                QObject::tr("no SpectraData"));
                            }
                        }
                    }

                  if(is_spectradata == false)
                    {
                      m_qxmlStreamReader.raiseError(
                        QObject::tr("no SpectraData"));
                    }
                }
            }
        }
      else
        {
          m_qxmlStreamReader.raiseError(QObject::tr("Not a MzIdentML file"));
          m_qxmlStreamReader.skipCurrentElement();
        }
    }

  else
    {
      m_qxmlStreamReader.raiseError(QObject::tr("Not a MzIdentML file"));
      m_qxmlStreamReader.skipCurrentElement();
    }
}

const QString &
MsRunLocationReader::getSpectraDataLocation() const
{
  return m_spectraDataLocation;
}


//<SpectraData
// location="/home/thierry/test/MS-GF+/20170308_test_dig_Liquide_01.mzXML"
// id="SID_1" name="20170308_test_dig_Liquide_01.mzXML">
//      <FileFormat>
//        <cvParam cvRef="PSI-MS" accession="MS:1000566" name="ISB mzXML
//        file"/>
//      </FileFormat>
//      <SpectrumIDFormat>
//        <cvParam cvRef="PSI-MS" accession="MS:1000776" name="scan number
//        only nativeID format"/>
//      </SpectrumIDFormat>
//    </SpectraData>

void
MsRunLocationReader::readSpectraData()
{
  qDebug();
  if(m_spectraDataLocation.isEmpty())
    {
      m_spectraDataLocation =
        m_qxmlStreamReader.attributes().value("location").toString();
      m_qxmlStreamReader.skipCurrentElement();
    }
  else
    {
      m_qxmlStreamReader.raiseError(QObject::tr(
        "ERROR : more than one SpectraData input file defined in Inputs "
        "DataCollection for this mzIdentML file"));
    }
  qDebug();
}
